"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _chai = require("chai");

var _graphql = require("graphql");

var _TypeDoc = _interopRequireDefault(require("../TypeDoc"));

var _ExampleSchema = require("../../__tests__/ExampleSchema");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 *  Copyright (c) 2019 GraphQL Contributors.
 *
 *  This source code is licensed under the MIT license found in the
 *  LICENSE file in the root directory of this source tree.
 */
describe('TypeDoc', function () {
  it('renders a top-level query object type', function () {
    var W = (0, _enzyme.mount)(_react.default.createElement(_TypeDoc.default, {
      schema: _ExampleSchema.ExampleSchema,
      type: _ExampleSchema.ExampleQuery,
      onClickType: jest.fn()
    }));
    var cats = W.find('.doc-category-item');
    (0, _chai.expect)(cats.at(0).text()).to.equal('string: String');
    (0, _chai.expect)(cats.at(1).text()).to.equal('union: exampleUnion');
    (0, _chai.expect)(cats.at(2).text()).to.equal('fieldWithArgs(stringArg: String): String');
  });
  it('handles onClickField and onClickType', function () {
    var onClickType = jest.fn();
    var onClickField = jest.fn();
    var W = (0, _enzyme.mount)(_react.default.createElement(_TypeDoc.default, {
      schema: _ExampleSchema.ExampleSchema,
      type: _ExampleSchema.ExampleQuery,
      onClickType: onClickType,
      onClickField: onClickField
    }));
    W.find('TypeLink').at(0).simulate('click');
    (0, _chai.expect)(onClickType.mock.calls.length).to.equal(1);
    (0, _chai.expect)(onClickType.mock.calls[0][0]).to.equal(_graphql.GraphQLString);
    W.find('.field-name').at(0).simulate('click');
    (0, _chai.expect)(onClickField.mock.calls.length).to.equal(1);
    (0, _chai.expect)(onClickField.mock.calls[0][0].name).to.equal('string');
    (0, _chai.expect)(onClickField.mock.calls[0][0].type).to.equal(_graphql.GraphQLString);
    (0, _chai.expect)(onClickField.mock.calls[0][1]).to.equal(_ExampleSchema.ExampleQuery);
  });
  it('renders deprecated fields when you click to see them', function () {
    var W = (0, _enzyme.mount)(_react.default.createElement(_TypeDoc.default, {
      schema: _ExampleSchema.ExampleSchema,
      type: _ExampleSchema.ExampleQuery,
      onClickType: jest.fn()
    }));
    var cats = W.find('.doc-category-item');
    (0, _chai.expect)(cats.length).to.equal(3);
    W.find('.show-btn').simulate('click');
    cats = W.find('.doc-category-item');
    (0, _chai.expect)(cats.length).to.equal(4);
    (0, _chai.expect)(W.find('.field-name').at(3).text()).to.equal('deprecatedField');
    (0, _chai.expect)(W.find('.doc-deprecation').at(0).text()).to.equal('example deprecation reason\n');
  });
  it('renders a Union type', function () {
    var W = (0, _enzyme.mount)(_react.default.createElement(_TypeDoc.default, {
      schema: _ExampleSchema.ExampleSchema,
      type: _ExampleSchema.ExampleUnion
    }));
    (0, _chai.expect)(W.find('.doc-category-title').at(0).text()).to.equal('possible types');
  });
  it('renders an Enum type', function () {
    var W = (0, _enzyme.mount)(_react.default.createElement(_TypeDoc.default, {
      schema: _ExampleSchema.ExampleSchema,
      type: _ExampleSchema.ExampleEnum
    }));
    (0, _chai.expect)(W.find('.doc-category-title').at(0).text()).to.equal('values');
    var enums = W.find('EnumValue');
    (0, _chai.expect)(enums.at(0).props().value.value).to.equal('Value 1');
    (0, _chai.expect)(enums.at(1).props().value.value).to.equal('Value 2');
  });
  it('shows deprecated enum values on click', function () {
    var W = (0, _enzyme.mount)(_react.default.createElement(_TypeDoc.default, {
      schema: _ExampleSchema.ExampleSchema,
      type: _ExampleSchema.ExampleEnum
    }));
    (0, _chai.expect)(W.state().showDeprecated).to.equal(false);
    var titles = W.find('.doc-category-title');
    (0, _chai.expect)(titles.at(0).text()).to.equal('values');
    (0, _chai.expect)(titles.at(1).text()).to.equal('deprecated values');
    var enums = W.find('EnumValue');
    (0, _chai.expect)(enums.length).to.equal(2); // click button to show deprecated enum values

    W.find('.show-btn').simulate('click');
    (0, _chai.expect)(W.state().showDeprecated).to.equal(true);
    enums = W.find('EnumValue');
    (0, _chai.expect)(enums.length).to.equal(3);
    (0, _chai.expect)(enums.at(2).props().value.value).to.equal('Value 3');
    (0, _chai.expect)(W.find('.doc-deprecation').at(1).text()).to.equal('Only two are needed\n');
  });
});